==> rascore-0.2.0-py3-none-any.whl: rascore/util/constants/pml.py <==
# -*- coding: utf-8 -*-
"""
MIT License

Copyright (c) 2022 Mitchell Isaac Parker

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""


sup_resids = "1-24:41-55:77-166"
show_resids = "1-166"

sup_pdb_code = "3k8y"
sup_chainid = "A"

mono_view = (
    -0.808012486,
    0.175240368,
    0.562499881,
    -0.249999866,
    -0.966506124,
    -0.058012813,
    0.533493519,
    -0.187499970,
    0.824759483,
    0.000000000,
    0.000000000,
    -118.513168335,
    -16.698070526,
    63.626861572,
    -77.002853394,
    93.436683655,
    143.589645386,
    -20.000000000,
)

gef_view = (
    0.534611464,
    0.124337271,
    0.835900784,
    0.124117725,
    -0.989943385,
    0.067869298,
    0.835933626,
    0.067466483,
    -0.544667661,
    0.000000000,
    0.000000000,
    -68.055381775,
    -15.691289902,
    80.045082092,
    -70.667411804,
    53.655380249,
    82.455383301,
    -20.000000000,
)

sw1_prot_view = (
    -0.213043734,
    0.124337271,
    0.969098508,
    0.039773643,
    -0.989943385,
    0.135755330,
    0.976232588,
    0.067466483,
    0.205956131,
    0.000000000,
    0.000000000,
    -85.069229126,
    -11.113093376,
    72.565818787,
    -68.772712708,
    67.069229126,
    103.069229126,
    -20.000000000,
)

sw2_prot_view = (
    -0.213043734,
    0.124337271,
    0.969098508,
    0.039773643,
    -0.989943385,
    0.135755330,
    0.976232588,
    0.067466483,
    0.205956131,
    0.000000000,
    0.000000000,
    -85.069229126,
    -20.004198074,
    59.417362213,
    -65.998970032,
    67.069229126,
    103.069229126,
    -20.000000000,
)

sw1_mono_view = (
    -0.808012486,
    0.175240368,
    0.562499881,
    -0.249999866,
    -0.966506124,
    -0.058012813,
    0.533493519,
    -0.187499970,
    0.824759483,
    0.000000000,
    0.000000000,
    -141.782043457,
    -11.824588776,
    72.831230164,
    -68.230155945,
    111.782043457,
    171.782043457,
    -20.000000000,
)

sw2_mono_view = (
    -0.808012486,
    0.175240368,
    0.562499881,
    -0.249999866,
    -0.966506124,
    -0.058012813,
    0.533493519,
    -0.187499970,
    0.824759483,
    0.000000000,
    0.000000000,
    -68.055381775,
    -22.664772034,
    59.600914001,
    -65.154541016,
    53.655380249,
    82.455383301,
    -20.000000000,
)

gap_view = (
    0.732742012,
    0.124337271,
    0.669050694,
    0.137454391,
    -0.989943445,
    0.033432692,
    0.666479588,
    0.067466483,
    -0.742464125,
    0.000000000,
    0.000000000,
    -56.712818146,
    -3.510648727,
    67.628509521,
    -65.662536621,
    44.712818146,
    68.712814331,
    -20.000000000,
)

y32_view = (
    -0.969098568,
    0.175240368,
    -0.173603624,
    -0.135755345,
    -0.966506124,
    -0.217797861,
    -0.205956131,
    -0.187499970,
    0.960429907,
    -0.000000000,
    0.000000000,
    -39.698974609,
    -4.438468933,
    66.992317200,
    -66.771186829,
    31.298973083,
    48.098976135,
    -20.000000000,
)

mut_view = (
    -0.808012486,
    0.175240368,
    0.562499881,
    -0.249999866,
    -0.966506124,
    -0.058012813,
    0.533493519,
    -0.187499970,
    0.824759483,
    0.000000000,
    0.000000000,
    -56.712818146,
    -9.198966980,
    65.702499390,
    -70.186019897,
    44.712818146,
    68.712814331,
    -20.000000000,
)

==> rascore-1.0.1-py3-none-any.whl: rascore/util/constants/pml.py <==
# -*- coding: utf-8 -*-
"""
  Copyright 2022 Mitchell Isaac Parker

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

"""


sup_resids = "1-24:41-55:77-166"
show_resids = "1-166"

sup_pdb_code = "3k8y"
sup_chainid = "A"

mono_view = (
    -0.808012486,
    0.175240368,
    0.562499881,
    -0.249999866,
    -0.966506124,
    -0.058012813,
    0.533493519,
    -0.187499970,
    0.824759483,
    0.000000000,
    0.000000000,
    -118.513168335,
    -16.698070526,
    63.626861572,
    -77.002853394,
    93.436683655,
    143.589645386,
    -20.000000000,
)

gef_view = (
    0.534611464,
    0.124337271,
    0.835900784,
    0.124117725,
    -0.989943385,
    0.067869298,
    0.835933626,
    0.067466483,
    -0.544667661,
    0.000000000,
    0.000000000,
    -68.055381775,
    -15.691289902,
    80.045082092,
    -70.667411804,
    53.655380249,
    82.455383301,
    -20.000000000,
)

sw1_prot_view = (
    -0.213043734,
    0.124337271,
    0.969098508,
    0.039773643,
    -0.989943385,
    0.135755330,
    0.976232588,
    0.067466483,
    0.205956131,
    0.000000000,
    0.000000000,
    -85.069229126,
    -11.113093376,
    72.565818787,
    -68.772712708,
    67.069229126,
    103.069229126,
    -20.000000000,
)

sw2_prot_view = (
    -0.213043734,
    0.124337271,
    0.969098508,
    0.039773643,
    -0.989943385,
    0.135755330,
    0.976232588,
    0.067466483,
    0.205956131,
    0.000000000,
    0.000000000,
    -85.069229126,
    -20.004198074,
    59.417362213,
    -65.998970032,
    67.069229126,
    103.069229126,
    -20.000000000,
)

sw1_mono_view = (
    -0.808012486,
    0.175240368,
    0.562499881,
    -0.249999866,
    -0.966506124,
    -0.058012813,
    0.533493519,
    -0.187499970,
    0.824759483,
    0.000000000,
    0.000000000,
    -141.782043457,
    -11.824588776,
    72.831230164,
    -68.230155945,
    111.782043457,
    171.782043457,
    -20.000000000,
)

sw2_mono_view = (
    -0.808012486,
    0.175240368,
    0.562499881,
    -0.249999866,
    -0.966506124,
    -0.058012813,
    0.533493519,
    -0.187499970,
    0.824759483,
    0.000000000,
    0.000000000,
    -68.055381775,
    -22.664772034,
    59.600914001,
    -65.154541016,
    53.655380249,
    82.455383301,
    -20.000000000,
)

gap_view = (
    0.732742012,
    0.124337271,
    0.669050694,
    0.137454391,
    -0.989943445,
    0.033432692,
    0.666479588,
    0.067466483,
    -0.742464125,
    0.000000000,
    0.000000000,
    -56.712818146,
    -3.510648727,
    67.628509521,
    -65.662536621,
    44.712818146,
    68.712814331,
    -20.000000000,
)

y32_view = (
    -0.969098568,
    0.175240368,
    -0.173603624,
    -0.135755345,
    -0.966506124,
    -0.217797861,
    -0.205956131,
    -0.187499970,
    0.960429907,
    -0.000000000,
    0.000000000,
    -39.698974609,
    -4.438468933,
    66.992317200,
    -66.771186829,
    31.298973083,
    48.098976135,
    -20.000000000,
)

mut_view = (
    -0.808012486,
    0.175240368,
    0.562499881,
    -0.249999866,
    -0.966506124,
    -0.058012813,
    0.533493519,
    -0.187499970,
    0.824759483,
    0.000000000,
    0.000000000,
    -56.712818146,
    -9.198966980,
    65.702499390,
    -70.186019897,
    44.712818146,
    68.712814331,
    -20.000000000,
)
